Learn R Programming

mvLSW (version 1.0)

summary.mvLSW: Summary of mvLSW Object

Description

Prints a summary of the information contained within a mvLSW classed object.

Usage

"summary"(object, ...)

Arguments

object
A mvLSW object.
...
Additional arguments.

Value

This command returns nothing, only prints a summary to the console.

Details

The command prints to screen a summary of the information contained within a mvLSW object. Information printed includes: dimensions, wavelet function, the smoothing regime applied, smoothing kernel(s), generalized cross-validation gamma deviance criteria score, application of the bias correction and minimum eigenvalue from across all spectral matries.

See Also

mvEWS, mvLSW.

Examples

Run this code
## Generate a bivariate time series
set.seed(100)
X <- matrix(rnorm(2 * 2^8), ncol = 2)
X[1:2^7, 2] <- 3 * (X[1:2^7, 2] + 0.95 * X[1:2^7, 1])
X[-(1:2^7), 2] <- X[-(1:2^7), 2] - 0.95 * X[-(1:2^7), 1]
X[-(1:2^7), 1] <- X[-(1:2^7), 1] * 4
X <- as.ts(X)

## Haar wavelet, apply same smoothing to all levels & optimize
EWS <- mvEWS(X, kernel.name = "daniell", kernel.param = 20, optimize = TRUE)
summary(EWS)
plot(EWS, style = 2, info = 1)

Run the code above in your browser using DataLab